@@ -1512,6 +1512,37 @@ mod test {
         assert!(a < 0.01 && a > -0.01);
     }
 
+    #[test]
+    #[cfg(feature = "is_in")]
+    fn test_lazy_query_8() -> Result<()> {
+        // https://github.com/pola-rs/polars/issues/842
+        let df = df![
+            "A" => [1, 2, 3],
+            "B" => [1, 2, 3],
+            "C" => [1, 2, 3],
+            "D" => [1, 2, 3],
+            "E" => [1, 2, 3]
+        ]?;
+
+        let mut selection = vec![];
+
+        for c in &["A", "B", "C", "D", "E"] {
+            let e = when(col(c).is_in(col("E")))
+                .then(col("A"))
+                .otherwise(Null {}.lit())
+                .alias(c);
+            selection.push(e);
+        }
+
+        let out = df
+            .lazy()
+            .select(selection)
+            .filter(col("D").gt(lit(1)))
+            .collect()?;
+        assert_eq!(out.shape(), (2, 5));
+        Ok(())
+    }
+
     #[test]
     fn test_lazy_shift_and_fill_all() {
         let data = &[1, 2, 3];
@@ -2250,4 +2281,25 @@ mod test {
         let out = df.lazy().filter(lit(true)).collect().unwrap();
         assert_eq!(out.shape(), (100, 1));
     }
+
+    #[test]
+    fn test_ternary_null() -> Result<()> {
+        let df = df![
+            "a" => ["a", "b", "c"]
+        ]?;
+
+        let out = df
+            .lazy()
+            .select(vec![when(col("a").eq(lit("c")))
+                .then(Null {}.lit())
+                .otherwise(col("a"))
+                .alias("foo")])
+            .collect()?;
+
+        assert_eq!(
+            out.column("foo")?.is_null().into_iter().collect::<Vec<_>>(),
+            &[Some(false), Some(false), Some(true)]
+        );
+        Ok(())
+    }
 }
